package com.zipcodewilmington.gildedrose;

import org.junit.Assert;
import org.junit.Test;

public class InventoryTest {
    @Test
    public void testBrieQuality() {
        Item brie = new Item("Aged Brie", 10, 45);
        Item[] item = {brie};
        Inventory inventory = new Inventory(item);

        inventory.updateQuality(brie);

        int expected = 46;
        int actual = brie.getQuality();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testBrieQuality_PastSellIn() {
        Item brie = new Item("Aged Brie", -2, 45);
        Item[] item = {brie};
        Inventory inventory = new Inventory(item);

        inventory.updateQuality(brie);

        int expected = 47;
        int actual = brie.getQuality();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testBackstageQuality() {
        Item backstage = new Item("Backstage passes to a TAFKAL80ETC concert", 15, 45);
        Item[] item = {backstage};
        Inventory inventory = new Inventory(item);

        inventory.updateQuality(backstage);

        int expected = 44;
        int actual = backstage.getQuality();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testBackstageQuality_LessThanTenDays() {
        Item backstage = new Item("Backstage passes to a TAFKAL80ETC concert", 8, 45);
        Item[] item = {backstage};
        Inventory inventory = new Inventory(item);

        inventory.updateQuality(backstage);

        int expected = 47;
        int actual = backstage.getQuality();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testBackstageQuality_LessThanFiveDays() {
        Item backstage = new Item("Backstage passes to a TAFKAL80ETC concert", 4, 45);
        Item[] item = {backstage};
        Inventory inventory = new Inventory(item);

        inventory.updateQuality(backstage);

        int expected = 48;
        int actual = backstage.getQuality();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testBackstageQuality_AfterConcert() {
        Item backstage = new Item("Backstage passes to a TAFKAL80ETC concert", 0, 50);
        Item[] item = {backstage};
        Inventory inventory = new Inventory(item);

        inventory.updateQuality(backstage);

        int expected = 0;
        int actual = backstage.getQuality();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testSulfurasQuality() {
        Item sulfuras = new Item("Sulfuras, Hand of Ragnaros", 10, 80);
        Item[] item = {sulfuras};
        Inventory inventory = new Inventory(item);

        inventory.updateQuality(sulfuras);

        int expected = 80;
        int actual = sulfuras.getQuality();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testNormalItemQuality() {
        Item normal = new Item("Generic Mana Potion", 10, 45);
        Item[] item = {normal};
        Inventory inventory = new Inventory(item);

        inventory.updateQuality(normal);

        int expected = 44;
        int actual = normal.getQuality();

        Assert.assertEquals(expected, actual);
    }


    @Test
    public void testNormalItemQuality_PastSellIn() {
        Item normal = new Item("Generic Mana Potion", -1, 10);
        Item[] item = {normal};
        Inventory inventory = new Inventory(item);

        inventory.updateQuality(normal);

        int expected = 8;
        int actual = normal.getQuality();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testConjuredItemQuality () {
        Item conjured = new Item("Sulfuros, Hand of Rognoros (not to be confused with Ragnaros)", 5, 45);
        Item[] item = {conjured};
        Inventory inventory = new Inventory(item);

        inventory.updateQuality(conjured);

        int expected = 43;
        int actual = conjured.getQuality();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testConjuredItemQuality_PastSellIn () {
        Item conjured = new Item("Sulfuros, Hand of Rognoros (not to be confused with Ragnaros)", -1, 10);
        Item[] item = {conjured};
        Inventory inventory = new Inventory(item);

        inventory.updateQuality(conjured);

        int expected = 6;
        int actual = conjured.getQuality();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testNormalItemSellIn () {
        Item normal = new Item("Generic Mana Potion", 5, 45);
        Item[] item = {normal};
        Inventory inventory = new Inventory(item);

        inventory.updateSellIn(normal);

        int expected = 4;
        int actual = normal.getSellIn();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testSulfurasItemSellIn () {
        Item sulfuras = new Item("Sulfuras, Hand of Ragnaros", 15, 45);
        Item[] item = {sulfuras};
        Inventory inventory = new Inventory(item);

        inventory.updateSellIn(sulfuras);

        int expected = 15;
        int actual = sulfuras.getSellIn();

        Assert.assertEquals(expected, actual);
    }

//    @Test
//    public void updateBrieQualityTest_PastSellIn() {
//        Item brie = new Item("Aged Brie", -2, 45);
//        Item[] item = {brie};
//        Inventory inventory = new Inventory(item);
//
//        inventory.updateQuality();
//
//        int expected = 47;
//        int actual = brie.getQuality();
//
//        Assert.assertEquals(expected, actual);
//    }

//    @Test
//    public void testIsAgedBrie() {
//        Item item = new Item("Aged Brie", 6, 50);
//
//        String expected = "Aged Brie";
//
//        String actual = item.getName();
//
//        Assert.assertEquals(expected, actual);
//    }
//
//    @Test
//    public void testIsBackstagePass() {
//        Item item = new Item("Backstage passes to a TAFKAL80ETC concert", 6, 50);
//
//        String expected = "Backstage passes to a TAFKAL80ETC concert";
//
//        String actual = item.getName();
//
//        Assert.assertEquals(expected, actual);
//    }
//
//    @Test
//    public void testIsSulfuras() {
//        Item item = new Item("Sulfuras, Hand of Ragnaros", 6, 50);
//
//        String expected = "Sulfuras, Hand of Ragnaros";
//
//        String actual = item.getName();
//
//        Assert.assertEquals(expected, actual);
//
//    }
}

